"""FortiOS CMDB - Installer category"""

from ..installer_base import Installer as InstallerBase
from .download import Download

__all__ = [
    "Download",
    "Installer",
]


class Installer(InstallerBase):
    """Installer endpoints wrapper for CMDB API."""

    def __init__(self, client):
        """Installer endpoints.
        
        Args:
            client: HTTP client instance for API communication
        """
        super().__init__(client)  # Initialize base class with GET methods
        self.download = Download(client)



"""FortiOS CMDB - Query category"""

from .abort import Abort

__all__ = [
    "Abort",
    "Query",
]


class Query:
    """Query endpoints wrapper for CMDB API."""

    def __init__(self, client):
        """Query endpoints.
        
        Args:
            client: HTTP client instance for API communication
        """
        self.abort = Abort(client)



""" - Type Stubs

Auto-generated stub file for type checking and IDE support.

Endpoint: wireless_controller/snmp
Category: cmdb
"""

from __future__ import annotations

from typing import (
    Any,
    ClassVar,
    Literal,
    TypedDict,
)

from hfortix_fortios.models import (
    FortiObject,
    FortiObjectList,
)


# ================================================================
# TypedDict Payloads
# ================================================================

class SnmpCommunityHostsItem(TypedDict, total=False):
    """Nested item for community.hosts field."""
    id: int
    ip: str


class SnmpCommunityHosts6Item(TypedDict, total=False):
    """Nested item for community.hosts6 field."""
    id: int
    ipv6: str


class SnmpCommunityItem(TypedDict, total=False):
    """Nested item for community field."""
    id: int
    name: str
    status: Literal["enable", "disable"]
    query_v1_status: Literal["enable", "disable"]
    query_v2c_status: Literal["enable", "disable"]
    trap_v1_status: Literal["enable", "disable"]
    trap_v2c_status: Literal["enable", "disable"]
    hosts: str | list[str] | list[SnmpCommunityHostsItem]
    hosts6: str | list[str] | list[SnmpCommunityHosts6Item]


class SnmpUserItem(TypedDict, total=False):
    """Nested item for user field."""
    name: str
    status: Literal["enable", "disable"]
    queries: Literal["enable", "disable"]
    trap_status: Literal["enable", "disable"]
    security_level: Literal["no-auth-no-priv", "auth-no-priv", "auth-priv"]
    auth_proto: Literal["md5", "sha", "sha224", "sha256", "sha384", "sha512"]
    auth_pwd: str
    priv_proto: Literal["aes", "des", "aes256", "aes256cisco"]
    priv_pwd: str
    notify_hosts: str | list[str]
    notify_hosts6: str | list[str]


class SnmpPayload(TypedDict, total=False):
    """Payload type for Snmp operations."""
    engine_id: str
    contact_info: str
    trap_high_cpu_threshold: int
    trap_high_mem_threshold: int
    community: str | list[str] | list[SnmpCommunityItem]
    user: str | list[str] | list[SnmpUserItem]


# ================================================================
# Response Types (TypedDict for dict-style access)
# ================================================================

class SnmpResponse(TypedDict, total=False):
    """Response type for Snmp - use with .dict property for typed dict access."""
    engine_id: str
    contact_info: str
    trap_high_cpu_threshold: int
    trap_high_mem_threshold: int
    community: list[SnmpCommunityItem]
    user: list[SnmpUserItem]


# ================================================================
# Response Types (Class for attribute access)
# ================================================================


class SnmpCommunityHostsItemObject(FortiObject[SnmpCommunityHostsItem]):
    """Typed object for community.hosts table items with attribute access."""
    id: int
    ip: str


class SnmpCommunityHosts6ItemObject(FortiObject[SnmpCommunityHosts6Item]):
    """Typed object for community.hosts6 table items with attribute access."""
    id: int
    ipv6: str


class SnmpCommunityItemObject(FortiObject[SnmpCommunityItem]):
    """Typed object for community table items with attribute access."""
    id: int
    name: str
    status: Literal["enable", "disable"]
    query_v1_status: Literal["enable", "disable"]
    query_v2c_status: Literal["enable", "disable"]
    trap_v1_status: Literal["enable", "disable"]
    trap_v2c_status: Literal["enable", "disable"]
    hosts: FortiObjectList[SnmpCommunityHostsItemObject]
    hosts6: FortiObjectList[SnmpCommunityHosts6ItemObject]


class SnmpUserItemObject(FortiObject[SnmpUserItem]):
    """Typed object for user table items with attribute access."""
    name: str
    status: Literal["enable", "disable"]
    queries: Literal["enable", "disable"]
    trap_status: Literal["enable", "disable"]
    security_level: Literal["no-auth-no-priv", "auth-no-priv", "auth-priv"]
    auth_proto: Literal["md5", "sha", "sha224", "sha256", "sha384", "sha512"]
    auth_pwd: str
    priv_proto: Literal["aes", "des", "aes256", "aes256cisco"]
    priv_pwd: str
    notify_hosts: str | list[str]
    notify_hosts6: str | list[str]


class SnmpObject(FortiObject):
    """Typed FortiObject for Snmp with field access."""
    engine_id: str
    contact_info: str
    trap_high_cpu_threshold: int
    trap_high_mem_threshold: int
    community: FortiObjectList[SnmpCommunityItemObject]
    user: FortiObjectList[SnmpUserItemObject]


# ================================================================
# Main Endpoint Class
# ================================================================

class Snmp:
    """
    
    Endpoint: wireless_controller/snmp
    Category: cmdb
    """
    
    # Class attributes for introspection
    endpoint: ClassVar[str] = ...
    path: ClassVar[str] = ...
    category: ClassVar[str] = ...
    capabilities: ClassVar[dict[str, Any]] = ...
    
    def __init__(self, client: Any) -> None:
        """Initialize endpoint with HTTP client."""
        ...
    
    # ================================================================
    # GET Methods
    # ================================================================
    
    # Singleton endpoint (no mkey)
    def get(
        self,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> SnmpObject: ...
    
    def get_schema(
        self,
        vdom: str | None = ...,
        format: str = ...,
    ) -> FortiObject: ...


    # ================================================================
    # PUT Method
    # ================================================================
    
    def put(
        self,
        payload_dict: SnmpPayload | None = ...,
        engine_id: str | None = ...,
        contact_info: str | None = ...,
        trap_high_cpu_threshold: int | None = ...,
        trap_high_mem_threshold: int | None = ...,
        community: str | list[str] | list[SnmpCommunityItem] | None = ...,
        user: str | list[str] | list[SnmpUserItem] | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> SnmpObject: ...


    # ================================================================
    # Utility Methods
    # ================================================================
    
    def exists(
        self,
        name: str,
        vdom: str | bool | None = ...,
    ) -> bool: ...
    
    def set(
        self,
        payload_dict: SnmpPayload | None = ...,
        engine_id: str | None = ...,
        contact_info: str | None = ...,
        trap_high_cpu_threshold: int | None = ...,
        trap_high_mem_threshold: int | None = ...,
        community: str | list[str] | list[SnmpCommunityItem] | None = ...,
        user: str | list[str] | list[SnmpUserItem] | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> FortiObject[Any]: ...
    
    # Helper methods
    @staticmethod
    def help(field_name: str | None = ...) -> str: ...
    
    @staticmethod
    def fields(detailed: bool = ...) -> list[str] | list[dict[str, Any]]: ...
    
    @staticmethod
    def field_info(field_name: str) -> FortiObject[Any]: ...
    
    @staticmethod
    def validate_field(name: str, value: Any) -> bool: ...
    
    @staticmethod
    def required_fields() -> list[str]: ...
    
    @staticmethod
    def defaults() -> FortiObject[Any]: ...
    
    @staticmethod
    def schema() -> FortiObject[Any]: ...


__all__ = [
    "Snmp",
    "SnmpPayload",
    "SnmpResponse",
    "SnmpObject",
]


"""FortiOS CMDB - Guest category"""

from .email import Email
from .sms import Sms

__all__ = [
    "Email",
    "Guest",
    "Sms",
]


class Guest:
    """Guest endpoints wrapper for CMDB API."""

    def __init__(self, client):
        """Guest endpoints.
        
        Args:
            client: HTTP client instance for API communication
        """
        self.email = Email(client)
        self.sms = Sms(client)



"""Type stubs for REPLACEMSG category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .admin import Admin
    from .alertmail import Alertmail
    from .auth import Auth
    from .automation import Automation
    from .fortiguard_wf import FortiguardWf
    from .http import Http
    from .mail import Mail
    from .nac_quar import NacQuar
    from .spam import Spam
    from .sslvpn import Sslvpn
    from .traffic_quota import TrafficQuota
    from .utm import Utm

__all__ = [
    "Admin",
    "Alertmail",
    "Auth",
    "Automation",
    "FortiguardWf",
    "Http",
    "Mail",
    "NacQuar",
    "Spam",
    "Sslvpn",
    "TrafficQuota",
    "Utm",
    "Replacemsg",
]


class Replacemsg:
    """REPLACEMSG API category.
    
    All endpoints return FortiObject instances with:
    - Attribute access: response.field
    - Dictionary access: response["field"]
    - Convert to dict: response.dict or response.json
    """
    
    admin: Admin
    alertmail: Alertmail
    auth: Auth
    automation: Automation
    fortiguard_wf: FortiguardWf
    http: Http
    mail: Mail
    nac_quar: NacQuar
    spam: Spam
    sslvpn: Sslvpn
    traffic_quota: TrafficQuota
    utm: Utm

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize replacemsg category with HTTP client."""
        ...



"""Type stubs for CONFIG category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .backup import Backup
    from .restore import Restore
    from .restore_status import RestoreStatus
    from .usb_filelist import UsbFilelist

__all__ = [
    "Backup",
    "Restore",
    "RestoreStatus",
    "UsbFilelist",
    "Config",
]


class Config:
    """CONFIG API category.
    
    All endpoints return FortiObject instances with:
    - Attribute access: response.field
    - Dictionary access: response["field"]
    - Convert to dict: response.dict or response.json
    """
    
    backup: Backup
    restore: Restore
    restore_status: RestoreStatus
    usb_filelist: UsbFilelist

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize config category with HTTP client."""
        ...



"""FortiOS CMDB - Lookup category"""

from ..lookup_base import Lookup as LookupBase
from .ha_peer import HaPeer

__all__ = [
    "HaPeer",
    "Lookup",
]


class Lookup(LookupBase):
    """Lookup endpoints wrapper for CMDB API."""

    def __init__(self, client):
        """Lookup endpoints.
        
        Args:
            client: HTTP client instance for API communication
        """
        super().__init__(client)  # Initialize base class with GET methods
        self.ha_peer = HaPeer(client)



"""
Pydantic Models for CMDB - webfilter/fortiguard

Runtime validation models for webfilter/fortiguard configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field
from typing import Any, Literal, Optional

# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================


# ============================================================================
# Main Model
# ============================================================================

class FortiguardModel(BaseModel):
    """
    Pydantic model for webfilter/fortiguard configuration.
    
    Configure FortiGuard Web Filter service.
    
    Validation Rules:        - cache_mode: pattern=        - cache_prefix_match: pattern=        - cache_mem_permille: min=1 max=150 pattern=        - ovrd_auth_port_http: min=0 max=65535 pattern=        - ovrd_auth_port_https: min=0 max=65535 pattern=        - ovrd_auth_port_https_flow: min=0 max=65535 pattern=        - ovrd_auth_port_warning: min=0 max=65535 pattern=        - ovrd_auth_https: pattern=        - warn_auth_https: pattern=        - close_ports: pattern=        - request_packet_size_limit: min=576 max=10000 pattern=        - embed_image: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    cache_mode: Literal["ttl", "db-ver"] | None = Field(default="ttl", description="Cache entry expiration mode.")    
    cache_prefix_match: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable prefix matching in the cache.")    
    cache_mem_permille: int | None = Field(ge=1, le=150, default=1, description="Maximum permille of available memory allocated to caching (1 - 150).")    
    ovrd_auth_port_http: int | None = Field(ge=0, le=65535, default=8008, description="Port to use for FortiGuard Web Filter HTTP override authentication.")    
    ovrd_auth_port_https: int | None = Field(ge=0, le=65535, default=8010, description="Port to use for FortiGuard Web Filter HTTPS override authentication in proxy mode.")    
    ovrd_auth_port_https_flow: int | None = Field(ge=0, le=65535, default=8015, description="Port to use for FortiGuard Web Filter HTTPS override authentication in flow mode.")    
    ovrd_auth_port_warning: int | None = Field(ge=0, le=65535, default=8020, description="Port to use for FortiGuard Web Filter Warning override authentication.")    
    ovrd_auth_https: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable use of HTTPS for override authentication.")    
    warn_auth_https: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable use of HTTPS for warning and authentication.")    
    close_ports: Literal["enable", "disable"] | None = Field(default="disable", description="Close ports used for HTTP/HTTPS override authentication and disable user overrides.")    
    request_packet_size_limit: int | None = Field(ge=576, le=10000, default=0, description="Limit size of URL request packets sent to FortiGuard server (0 for default).")    
    embed_image: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable embedding images into replacement messages (default = enable).")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "FortiguardModel":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "FortiguardModel",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.2
# Generated: 2026-01-21T16:24:02.426330Z
# ============================================================================


"""
Pydantic Models for CMDB - application/group

Runtime validation models for application/group configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field
from typing import Any, Literal, Optional
from enum import Enum

# ============================================================================
# Enum Definitions for Child Table Fields (for fields with 4+ allowed values)
# ============================================================================

# ============================================================================
# Child Table Models (sorted deepest-first so nested models are defined before their parents)
# ============================================================================

class GroupRisk(BaseModel):
    """
    Child table model for risk.
    
    Risk, or impact, of allowing traffic from this application to occur (1 - 5; Low, Elevated, Medium, High, and Critical).
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    level: int = Field(ge=0, le=4294967295, default=0, description="Risk, or impact, of allowing traffic from this application to occur (1 - 5; Low, Elevated, Medium, High, and Critical).")
class GroupCategory(BaseModel):
    """
    Child table model for category.
    
    Application category ID list.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    id_: int = Field(ge=0, le=4294967295, default=0, serialization_alias="id", description="Category IDs.")
class GroupApplication(BaseModel):
    """
    Child table model for application.
    
    Application ID list.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    id_: int = Field(ge=0, le=4294967295, default=0, serialization_alias="id", description="Application IDs.")
# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================

class GroupPopularityEnum(str, Enum):
    """Allowed values for popularity field."""
    V_1 = "1"
    V_2 = "2"
    V_3 = "3"
    V_4 = "4"
    V_5 = "5"


# ============================================================================
# Main Model
# ============================================================================

class GroupModel(BaseModel):
    """
    Pydantic model for application/group configuration.
    
    Configure firewall application groups.
    
    Validation Rules:        - name: max_length=63 pattern=        - comment: max_length=255 pattern=        - type_: pattern=        - application: pattern=        - category: pattern=        - risk: pattern=        - protocols: pattern=        - vendor: pattern=        - technology: pattern=        - behavior: pattern=        - popularity: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    name: str | None = Field(max_length=63, default=None, description="Application group name.")    
    comment: str | None = Field(max_length=255, default=None, description="Comments.")    
    type_: Literal["application", "filter"] | None = Field(default="application", serialization_alias="type", description="Application group type.")    
    application: list[GroupApplication] = Field(default_factory=list, description="Application ID list.")    
    category: list[GroupCategory] = Field(default_factory=list, description="Application category ID list.")    
    risk: list[GroupRisk] = Field(default_factory=list, description="Risk, or impact, of allowing traffic from this application to occur (1 - 5; Low, Elevated, Medium, High, and Critical).")    
    protocols: list[str] = Field(default_factory=list, description="Application protocol filter.")    
    vendor: list[str] = Field(default_factory=list, description="Application vendor filter.")    
    technology: list[str] = Field(default_factory=list, description="Application technology filter.")    
    behavior: list[str] = Field(default_factory=list, description="Application behavior filter.")    
    popularity: list[GroupPopularityEnum] = Field(default_factory=list, description="Application popularity filter (1 - 5, from least to most popular).")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "GroupModel":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "GroupModel",    "GroupApplication",    "GroupCategory",    "GroupRisk",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.2
# Generated: 2026-01-21T16:24:00.938325Z
# ============================================================================


"""FortiOS CMDB - Acl category (stub)"""

from typing import Any
from ..acl_base import Acl as AclBase
from .clear_counters import ClearCounters

class Acl(AclBase):
    """Acl endpoints wrapper for CMDB API."""

    clear_counters: ClearCounters

    def __init__(self, client: Any) -> None:
        """Initialize endpoint with HTTP client."""
        ...



"""FortiOS CMDB - SecurityPolicy category"""

from .local_access import LocalAccess
from .x802_1x import X8021x

__all__ = [
    "LocalAccess",
    "SecurityPolicy",
    "X8021x",
]


class SecurityPolicy:
    """SecurityPolicy endpoints wrapper for CMDB API."""

    def __init__(self, client):
        """SecurityPolicy endpoints.
        
        Args:
            client: HTTP client instance for API communication
        """
        self.local_access = LocalAccess(client)
        self.x802_1x = X8021x(client)



"""
Pydantic Models for CMDB - system/password_policy

Runtime validation models for system/password_policy configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field
from typing import Any, Literal, Optional

# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================


# ============================================================================
# Main Model
# ============================================================================

class PasswordPolicyModel(BaseModel):
    """
    Pydantic model for system/password_policy configuration.
    
    Configure password policy for locally defined administrator passwords and IPsec VPN pre-shared keys.
    
    Validation Rules:        - status: pattern=        - apply_to: pattern=        - minimum_length: min=12 max=128 pattern=        - min_lower_case_letter: min=0 max=128 pattern=        - min_upper_case_letter: min=0 max=128 pattern=        - min_non_alphanumeric: min=0 max=128 pattern=        - min_number: min=0 max=128 pattern=        - expire_status: pattern=        - expire_day: min=1 max=999 pattern=        - reuse_password: pattern=        - reuse_password_limit: min=0 max=20 pattern=        - login_lockout_upon_weaker_encryption: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    status: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable setting a password policy for locally defined administrator passwords and IPsec VPN pre-shared keys.")    
    apply_to: list[Literal["admin-password", "ipsec-preshared-key"]] = Field(default_factory=list, description="Apply password policy to administrator passwords or IPsec pre-shared keys or both. Separate entries with a space.")    
    minimum_length: int | None = Field(ge=12, le=128, default=12, description="Minimum password length (12 - 128, default = 12).")    
    min_lower_case_letter: int | None = Field(ge=0, le=128, default=1, description="Minimum number of lowercase characters in password (0 - 128, default = 1).")    
    min_upper_case_letter: int | None = Field(ge=0, le=128, default=1, description="Minimum number of uppercase characters in password (0 - 128, default = 1).")    
    min_non_alphanumeric: int | None = Field(ge=0, le=128, default=1, description="Minimum number of non-alphanumeric characters in password (0 - 128, default = 1).")    
    min_number: int | None = Field(ge=0, le=128, default=1, description="Minimum number of numeric characters in password (0 - 128, default = 1).")    
    expire_status: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable password expiration.")    
    expire_day: int | None = Field(ge=1, le=999, default=90, description="Number of days after which passwords expire (1 - 999 days, default = 90).")    
    reuse_password: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable reuse of password.")    
    reuse_password_limit: int | None = Field(ge=0, le=20, default=0, description="Number of times passwords can be reused (0 - 20, default = 0. If set to 0, can reuse password an unlimited number of times.).")    
    login_lockout_upon_weaker_encryption: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable administrative user login lockout upon downgrade (defaut = disable). If enabled, changing the FortiOS firmware to a version where safer passwords are unsupported will lock out administrative users.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "PasswordPolicyModel":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "PasswordPolicyModel",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.2
# Generated: 2026-01-21T16:24:01.643527Z
# ============================================================================


"""Validation helpers for endpoint_control/fctems - Auto-generated"""

from typing import Any, TypedDict, Literal
from typing_extensions import NotRequired

# Import common validators from central _helpers module
from hfortix_fortios._helpers import (
    validate_enable_disable,
    validate_integer_range,
    validate_string_length,
    validate_port_number,
    validate_ip_address,
    validate_ipv6_address,
    validate_mac_address,
)

# Import central validation functions (avoid duplication across 1,062 files)
from hfortix_fortios._helpers.validation import (
    validate_required_fields as _validate_required_fields,
    validate_enum_field as _validate_enum_field,
    validate_query_parameter as _validate_query_parameter,
)

# ============================================================================
# Required Fields Validation
# Auto-generated from schema
# ============================================================================

# ⚠️  IMPORTANT: FortiOS schemas have known issues with required field marking:

# Do NOT use this list for strict validation - test with the actual FortiOS API!

# Fields marked as required (after filtering false positives)
REQUIRED_FIELDS = [
    "interface",  # Specify outgoing interface to reach server.
]

# Fields with defaults (optional)
FIELDS_WITH_DEFAULTS = {
    "ems-id": 0,
    "status": "disable",
    "name": "",
    "dirty-reason": "none",
    "fortinetone-cloud-authentication": "disable",
    "server": "",
    "https-port": 443,
    "serial-number": "",
    "tenant-id": "",
    "source-ip": "0.0.0.0",
    "pull-sysinfo": "enable",
    "pull-vulnerabilities": "enable",
    "pull-tags": "enable",
    "pull-malware-hash": "enable",
    "capabilities": "",
    "call-timeout": 30,
    "out-of-sync-threshold": 180,
    "send-tags-to-all-vdoms": "disable",
    "websocket-override": "disable",
    "interface-select-method": "auto",
    "interface": "",
    "trust-ca-cn": "enable",
    "verifying-ca": "",
}

# ============================================================================
# Deprecated Fields
# Auto-generated from schema - warns users about deprecated fields
# ============================================================================

# Deprecated fields with migration guidance
DEPRECATED_FIELDS = {
}

# ============================================================================
# Field Metadata (Type Information & Descriptions)
# Auto-generated from schema - use for IDE autocomplete and documentation
# ============================================================================

# Field types mapping
FIELD_TYPES = {
    "ems-id": "integer",  # EMS ID in order (1 - 7).
    "status": "option",  # Enable or disable this EMS configuration.
    "name": "string",  # FortiClient Enterprise Management Server (EMS) name.
    "dirty-reason": "option",  # Dirty Reason for FortiClient EMS.
    "fortinetone-cloud-authentication": "option",  # Enable/disable authentication of FortiClient EMS Cloud throu
    "cloud-authentication-access-key": "password",  # FortiClient EMS Cloud multitenancy access key
    "server": "string",  # FortiClient EMS FQDN or IPv4 address.
    "https-port": "integer",  # FortiClient EMS HTTPS access port number. (1 - 65535, defaul
    "serial-number": "string",  # EMS Serial Number.
    "tenant-id": "string",  # EMS Tenant ID.
    "source-ip": "ipv4-address-any",  # REST API call source IP.
    "pull-sysinfo": "option",  # Enable/disable pulling SysInfo from EMS.
    "pull-vulnerabilities": "option",  # Enable/disable pulling vulnerabilities from EMS.
    "pull-tags": "option",  # Enable/disable pulling FortiClient user tags from EMS.
    "pull-malware-hash": "option",  # Enable/disable pulling FortiClient malware hash from EMS.
    "capabilities": "option",  # List of EMS capabilities.
    "call-timeout": "integer",  # FortiClient EMS call timeout in seconds (1 - 180 seconds, de
    "out-of-sync-threshold": "integer",  # Outdated resource threshold in seconds (10 - 3600, default =
    "send-tags-to-all-vdoms": "option",  # Relax restrictions on tags to send all EMS tags to all VDOMs
    "websocket-override": "option",  # Enable/disable override behavior for how this FortiGate unit
    "interface-select-method": "option",  # Specify how to select outgoing interface to reach server.
    "interface": "string",  # Specify outgoing interface to reach server.
    "trust-ca-cn": "option",  # Enable/disable trust of the EMS certificate issuer(CA) and c
    "verifying-ca": "string",  # Lowest CA cert on Fortigate in verified EMS cert chain.
}

# Field descriptions (help text from FortiOS API)
FIELD_DESCRIPTIONS = {
    "ems-id": "EMS ID in order (1 - 7).",
    "status": "Enable or disable this EMS configuration.",
    "name": "FortiClient Enterprise Management Server (EMS) name.",
    "dirty-reason": "Dirty Reason for FortiClient EMS.",
    "fortinetone-cloud-authentication": "Enable/disable authentication of FortiClient EMS Cloud through FortiCloud account.",
    "cloud-authentication-access-key": "FortiClient EMS Cloud multitenancy access key",
    "server": "FortiClient EMS FQDN or IPv4 address.",
    "https-port": "FortiClient EMS HTTPS access port number. (1 - 65535, default: 443).",
    "serial-number": "EMS Serial Number.",
    "tenant-id": "EMS Tenant ID.",
    "source-ip": "REST API call source IP.",
    "pull-sysinfo": "Enable/disable pulling SysInfo from EMS.",
    "pull-vulnerabilities": "Enable/disable pulling vulnerabilities from EMS.",
    "pull-tags": "Enable/disable pulling FortiClient user tags from EMS.",
    "pull-malware-hash": "Enable/disable pulling FortiClient malware hash from EMS.",
    "capabilities": "List of EMS capabilities.",
    "call-timeout": "FortiClient EMS call timeout in seconds (1 - 180 seconds, default = 30).",
    "out-of-sync-threshold": "Outdated resource threshold in seconds (10 - 3600, default = 180).",
    "send-tags-to-all-vdoms": "Relax restrictions on tags to send all EMS tags to all VDOMs",
    "websocket-override": "Enable/disable override behavior for how this FortiGate unit connects to EMS using a WebSocket connection.",
    "interface-select-method": "Specify how to select outgoing interface to reach server.",
    "interface": "Specify outgoing interface to reach server.",
    "trust-ca-cn": "Enable/disable trust of the EMS certificate issuer(CA) and common name(CN) for certificate auto-renewal.",
    "verifying-ca": "Lowest CA cert on Fortigate in verified EMS cert chain.",
}

# Field constraints (string lengths, integer ranges)
FIELD_CONSTRAINTS = {
    "ems-id": {"type": "integer", "min": 1, "max": 7},
    "name": {"type": "string", "max_length": 35},
    "server": {"type": "string", "max_length": 255},
    "https-port": {"type": "integer", "min": 1, "max": 65535},
    "serial-number": {"type": "string", "max_length": 16},
    "tenant-id": {"type": "string", "max_length": 32},
    "call-timeout": {"type": "integer", "min": 1, "max": 180},
    "out-of-sync-threshold": {"type": "integer", "min": 10, "max": 3600},
    "interface": {"type": "string", "max_length": 15},
    "verifying-ca": {"type": "string", "max_length": 79},
}

# Nested schemas (for table/list fields with children)
NESTED_SCHEMAS = {
}


# Valid enum values from API documentation
VALID_BODY_STATUS = [
    "enable",
    "disable",
]
VALID_BODY_DIRTY_REASON = [
    "none",
    "mismatched-ems-sn",
]
VALID_BODY_FORTINETONE_CLOUD_AUTHENTICATION = [
    "enable",
    "disable",
]
VALID_BODY_PULL_SYSINFO = [
    "enable",
    "disable",
]
VALID_BODY_PULL_VULNERABILITIES = [
    "enable",
    "disable",
]
VALID_BODY_PULL_TAGS = [
    "enable",
    "disable",
]
VALID_BODY_PULL_MALWARE_HASH = [
    "enable",
    "disable",
]
VALID_BODY_CAPABILITIES = [
    "fabric-auth",
    "silent-approval",
    "websocket",
    "websocket-malware",
    "push-ca-certs",
    "common-tags-api",
    "tenant-id",
    "client-avatars",
    "single-vdom-connector",
    "fgt-sysinfo-api",
    "ztna-server-info",
    "used-tags",
]
VALID_BODY_SEND_TAGS_TO_ALL_VDOMS = [
    "enable",
    "disable",
]
VALID_BODY_WEBSOCKET_OVERRIDE = [
    "enable",
    "disable",
]
VALID_BODY_INTERFACE_SELECT_METHOD = [
    "auto",
    "sdwan",
    "specify",
]
VALID_BODY_TRUST_CA_CN = [
    "enable",
    "disable",
]
VALID_QUERY_ACTION = ["default", "schema"]

# ============================================================================
# GET Validation
# ============================================================================


def validate_endpoint_control_fctems_get(
    attr: str | None = None,
    filters: dict[str, Any] | None = None,
    **params: Any,
) -> tuple[bool, str | None]:
    """Validate GET request parameters for endpoint_control/fctems."""
    # Validate query parameters using central function
    if "action" in params:
        is_valid, error = _validate_query_parameter(
            "action",
            params.get("action"),
            VALID_QUERY_ACTION
        )
        if not is_valid:
            return (False, error)

    return (True, None)


# ============================================================================
# POST Validation
# ============================================================================


def validate_endpoint_control_fctems_post(
    payload: dict,
    **params: Any,
) -> tuple[bool, str | None]:
    """Validate POST request to create new endpoint_control/fctems object."""
    # Step 1: Validate required fields using central function
    is_valid, error = _validate_required_fields(
        payload,
        REQUIRED_FIELDS,
        FIELD_DESCRIPTIONS
    )
    if not is_valid:
        return (False, error)

    # Step 2: Validate enum values using central function
    if "status" in payload:
        is_valid, error = _validate_enum_field(
            "status",
            payload["status"],
            VALID_BODY_STATUS,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "dirty-reason" in payload:
        is_valid, error = _validate_enum_field(
            "dirty-reason",
            payload["dirty-reason"],
            VALID_BODY_DIRTY_REASON,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "fortinetone-cloud-authentication" in payload:
        is_valid, error = _validate_enum_field(
            "fortinetone-cloud-authentication",
            payload["fortinetone-cloud-authentication"],
            VALID_BODY_FORTINETONE_CLOUD_AUTHENTICATION,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "pull-sysinfo" in payload:
        is_valid, error = _validate_enum_field(
            "pull-sysinfo",
            payload["pull-sysinfo"],
            VALID_BODY_PULL_SYSINFO,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "pull-vulnerabilities" in payload:
        is_valid, error = _validate_enum_field(
            "pull-vulnerabilities",
            payload["pull-vulnerabilities"],
            VALID_BODY_PULL_VULNERABILITIES,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "pull-tags" in payload:
        is_valid, error = _validate_enum_field(
            "pull-tags",
            payload["pull-tags"],
            VALID_BODY_PULL_TAGS,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "pull-malware-hash" in payload:
        is_valid, error = _validate_enum_field(
            "pull-malware-hash",
            payload["pull-malware-hash"],
            VALID_BODY_PULL_MALWARE_HASH,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "capabilities" in payload:
        is_valid, error = _validate_enum_field(
            "capabilities",
            payload["capabilities"],
            VALID_BODY_CAPABILITIES,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "send-tags-to-all-vdoms" in payload:
        is_valid, error = _validate_enum_field(
            "send-tags-to-all-vdoms",
            payload["send-tags-to-all-vdoms"],
            VALID_BODY_SEND_TAGS_TO_ALL_VDOMS,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "websocket-override" in payload:
        is_valid, error = _validate_enum_field(
            "websocket-override",
            payload["websocket-override"],
            VALID_BODY_WEBSOCKET_OVERRIDE,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "interface-select-method" in payload:
        is_valid, error = _validate_enum_field(
            "interface-select-method",
            payload["interface-select-method"],
            VALID_BODY_INTERFACE_SELECT_METHOD,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "trust-ca-cn" in payload:
        is_valid, error = _validate_enum_field(
            "trust-ca-cn",
            payload["trust-ca-cn"],
            VALID_BODY_TRUST_CA_CN,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)

    return (True, None)


# ============================================================================
# PUT Validation
# ============================================================================


def validate_endpoint_control_fctems_put(
    payload: dict,
    **params: Any,
) -> tuple[bool, str | None]:
    """Validate PUT request to update endpoint_control/fctems."""
    # Validate enum values using central function
    if "status" in payload:
        is_valid, error = _validate_enum_field(
            "status",
            payload["status"],
            VALID_BODY_STATUS,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "dirty-reason" in payload:
        is_valid, error = _validate_enum_field(
            "dirty-reason",
            payload["dirty-reason"],
            VALID_BODY_DIRTY_REASON,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "fortinetone-cloud-authentication" in payload:
        is_valid, error = _validate_enum_field(
            "fortinetone-cloud-authentication",
            payload["fortinetone-cloud-authentication"],
            VALID_BODY_FORTINETONE_CLOUD_AUTHENTICATION,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "pull-sysinfo" in payload:
        is_valid, error = _validate_enum_field(
            "pull-sysinfo",
            payload["pull-sysinfo"],
            VALID_BODY_PULL_SYSINFO,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "pull-vulnerabilities" in payload:
        is_valid, error = _validate_enum_field(
            "pull-vulnerabilities",
            payload["pull-vulnerabilities"],
            VALID_BODY_PULL_VULNERABILITIES,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "pull-tags" in payload:
        is_valid, error = _validate_enum_field(
            "pull-tags",
            payload["pull-tags"],
            VALID_BODY_PULL_TAGS,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "pull-malware-hash" in payload:
        is_valid, error = _validate_enum_field(
            "pull-malware-hash",
            payload["pull-malware-hash"],
            VALID_BODY_PULL_MALWARE_HASH,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "capabilities" in payload:
        is_valid, error = _validate_enum_field(
            "capabilities",
            payload["capabilities"],
            VALID_BODY_CAPABILITIES,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "send-tags-to-all-vdoms" in payload:
        is_valid, error = _validate_enum_field(
            "send-tags-to-all-vdoms",
            payload["send-tags-to-all-vdoms"],
            VALID_BODY_SEND_TAGS_TO_ALL_VDOMS,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "websocket-override" in payload:
        is_valid, error = _validate_enum_field(
            "websocket-override",
            payload["websocket-override"],
            VALID_BODY_WEBSOCKET_OVERRIDE,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "interface-select-method" in payload:
        is_valid, error = _validate_enum_field(
            "interface-select-method",
            payload["interface-select-method"],
            VALID_BODY_INTERFACE_SELECT_METHOD,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "trust-ca-cn" in payload:
        is_valid, error = _validate_enum_field(
            "trust-ca-cn",
            payload["trust-ca-cn"],
            VALID_BODY_TRUST_CA_CN,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)

    return (True, None)


# ============================================================================
# Metadata Access Functions
# Imported from central module to avoid duplication across 1,062 files
# Bound to this endpoint's data using functools.partial (saves ~7KB per file)
# ============================================================================

from functools import partial
from hfortix_fortios._helpers.metadata import (
    get_field_description,
    get_field_type,
    get_field_constraints,
    get_field_default,
    get_field_options,
    get_nested_schema,
    get_all_fields,
    get_field_metadata,
    validate_field_value,
)

# Bind module-specific data to central functions using partial application
get_field_description = partial(get_field_description, FIELD_DESCRIPTIONS)
get_field_type = partial(get_field_type, FIELD_TYPES)
get_field_constraints = partial(get_field_constraints, FIELD_CONSTRAINTS)
get_field_default = partial(get_field_default, FIELDS_WITH_DEFAULTS)
get_field_options = partial(get_field_options, globals())
get_nested_schema = partial(get_nested_schema, NESTED_SCHEMAS)
get_all_fields = partial(get_all_fields, FIELD_TYPES)
get_field_metadata = partial(get_field_metadata, FIELD_TYPES, FIELD_DESCRIPTIONS, 
                             FIELD_CONSTRAINTS, FIELDS_WITH_DEFAULTS, REQUIRED_FIELDS,
                             NESTED_SCHEMAS, globals())
validate_field_value = partial(validate_field_value, FIELD_TYPES, FIELD_DESCRIPTIONS,
                               FIELD_CONSTRAINTS, globals())


# ============================================================================
# Schema Information
# Metadata about this endpoint schema
# ============================================================================

SCHEMA_INFO = {
    "endpoint": "endpoint_control/fctems",
    "category": "cmdb",
    "api_path": "endpoint-control/fctems",
    "mkey": "ems-id",
    "mkey_type": "integer",
    "help": "Configure FortiClient Enterprise Management Server (EMS) entries.",
    "total_fields": 24,
    "required_fields_count": 1,
    "fields_with_defaults_count": 23,
}


def get_schema_info() -> dict[str, Any]:
    """Get information about this endpoint schema."""
    return SCHEMA_INFO.copy()



""" - Type Stubs

Auto-generated stub file for type checking and IDE support.

Endpoint: firewall/sniffer
Category: cmdb
"""

from __future__ import annotations

from typing import (
    Any,
    ClassVar,
    Literal,
    TypedDict,
    overload,
)

from hfortix_fortios.models import (
    FortiObject,
    FortiObjectList,
)


# ================================================================
# TypedDict Payloads
# ================================================================

class SnifferIpthreatfeedItem(TypedDict, total=False):
    """Nested item for ip-threatfeed field."""
    name: str


class SnifferAnomalyItem(TypedDict, total=False):
    """Nested item for anomaly field."""
    name: str
    status: Literal["disable", "enable"]
    log: Literal["enable", "disable"]
    action: Literal["pass", "block"]
    quarantine: Literal["none", "attacker"]
    quarantine_expiry: str
    quarantine_log: Literal["disable", "enable"]
    threshold: int
    threshold_default: int


class SnifferPayload(TypedDict, total=False):
    """Payload type for Sniffer operations."""
    id: int
    uuid: str
    status: Literal["enable", "disable"]
    logtraffic: Literal["all", "utm", "disable"]
    ipv6: Literal["enable", "disable"]
    non_ip: Literal["enable", "disable"]
    interface: str
    host: str
    port: str
    protocol: str
    vlan: str
    application_list_status: Literal["enable", "disable"]
    application_list: str
    ips_sensor_status: Literal["enable", "disable"]
    ips_sensor: str
    dsri: Literal["enable", "disable"]
    av_profile_status: Literal["enable", "disable"]
    av_profile: str
    webfilter_profile_status: Literal["enable", "disable"]
    webfilter_profile: str
    emailfilter_profile_status: Literal["enable", "disable"]
    emailfilter_profile: str
    dlp_profile_status: Literal["enable", "disable"]
    dlp_profile: str
    ip_threatfeed_status: Literal["enable", "disable"]
    ip_threatfeed: str | list[str] | list[SnifferIpthreatfeedItem]
    file_filter_profile_status: Literal["enable", "disable"]
    file_filter_profile: str
    ips_dos_status: Literal["enable", "disable"]
    anomaly: str | list[str] | list[SnifferAnomalyItem]


# ================================================================
# Response Types (TypedDict for dict-style access)
# ================================================================

class SnifferResponse(TypedDict, total=False):
    """Response type for Sniffer - use with .dict property for typed dict access."""
    id: int
    uuid: str
    status: Literal["enable", "disable"]
    logtraffic: Literal["all", "utm", "disable"]
    ipv6: Literal["enable", "disable"]
    non_ip: Literal["enable", "disable"]
    interface: str
    host: str
    port: str
    protocol: str
    vlan: str
    application_list_status: Literal["enable", "disable"]
    application_list: str
    ips_sensor_status: Literal["enable", "disable"]
    ips_sensor: str
    dsri: Literal["enable", "disable"]
    av_profile_status: Literal["enable", "disable"]
    av_profile: str
    webfilter_profile_status: Literal["enable", "disable"]
    webfilter_profile: str
    emailfilter_profile_status: Literal["enable", "disable"]
    emailfilter_profile: str
    dlp_profile_status: Literal["enable", "disable"]
    dlp_profile: str
    ip_threatfeed_status: Literal["enable", "disable"]
    ip_threatfeed: list[SnifferIpthreatfeedItem]
    file_filter_profile_status: Literal["enable", "disable"]
    file_filter_profile: str
    ips_dos_status: Literal["enable", "disable"]
    anomaly: list[SnifferAnomalyItem]


# ================================================================
# Response Types (Class for attribute access)
# ================================================================


class SnifferIpthreatfeedItemObject(FortiObject[SnifferIpthreatfeedItem]):
    """Typed object for ip-threatfeed table items with attribute access."""
    name: str


class SnifferAnomalyItemObject(FortiObject[SnifferAnomalyItem]):
    """Typed object for anomaly table items with attribute access."""
    name: str
    status: Literal["disable", "enable"]
    log: Literal["enable", "disable"]
    action: Literal["pass", "block"]
    quarantine: Literal["none", "attacker"]
    quarantine_expiry: str
    quarantine_log: Literal["disable", "enable"]
    threshold: int
    threshold_default: int


class SnifferObject(FortiObject):
    """Typed FortiObject for Sniffer with field access."""
    id: int
    uuid: str
    status: Literal["enable", "disable"]
    logtraffic: Literal["all", "utm", "disable"]
    ipv6: Literal["enable", "disable"]
    non_ip: Literal["enable", "disable"]
    interface: str
    host: str
    port: str
    protocol: str
    vlan: str
    application_list_status: Literal["enable", "disable"]
    application_list: str
    ips_sensor_status: Literal["enable", "disable"]
    ips_sensor: str
    dsri: Literal["enable", "disable"]
    av_profile_status: Literal["enable", "disable"]
    av_profile: str
    webfilter_profile_status: Literal["enable", "disable"]
    webfilter_profile: str
    emailfilter_profile_status: Literal["enable", "disable"]
    emailfilter_profile: str
    dlp_profile_status: Literal["enable", "disable"]
    dlp_profile: str
    ip_threatfeed_status: Literal["enable", "disable"]
    ip_threatfeed: FortiObjectList[SnifferIpthreatfeedItemObject]
    file_filter_profile_status: Literal["enable", "disable"]
    file_filter_profile: str
    ips_dos_status: Literal["enable", "disable"]
    anomaly: FortiObjectList[SnifferAnomalyItemObject]


# ================================================================
# Main Endpoint Class
# ================================================================

class Sniffer:
    """
    
    Endpoint: firewall/sniffer
    Category: cmdb
    MKey: id
    """
    
    # Class attributes for introspection
    endpoint: ClassVar[str] = ...
    path: ClassVar[str] = ...
    category: ClassVar[str] = ...
    mkey: ClassVar[str] = ...
    capabilities: ClassVar[dict[str, Any]] = ...
    
    def __init__(self, client: Any) -> None:
        """Initialize endpoint with HTTP client."""
        ...
    
    # ================================================================
    # GET Methods
    # ================================================================
    
    # CMDB with mkey - overloads for single vs list returns
    @overload
    def get(
        self,
        id: int,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> SnifferObject: ...
    
    @overload
    def get(
        self,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> FortiObjectList[SnifferObject]: ...
    
    def get_schema(
        self,
        vdom: str | None = ...,
        format: str = ...,
    ) -> FortiObject: ...

    # ================================================================
    # POST Method
    # ================================================================
    
    def post(
        self,
        payload_dict: SnifferPayload | None = ...,
        id: int | None = ...,
        uuid: str | None = ...,
        status: Literal["enable", "disable"] | None = ...,
        logtraffic: Literal["all", "utm", "disable"] | None = ...,
        ipv6: Literal["enable", "disable"] | None = ...,
        non_ip: Literal["enable", "disable"] | None = ...,
        interface: str | None = ...,
        host: str | None = ...,
        port: str | None = ...,
        protocol: str | None = ...,
        vlan: str | None = ...,
        application_list_status: Literal["enable", "disable"] | None = ...,
        application_list: str | None = ...,
        ips_sensor_status: Literal["enable", "disable"] | None = ...,
        ips_sensor: str | None = ...,
        dsri: Literal["enable", "disable"] | None = ...,
        av_profile_status: Literal["enable", "disable"] | None = ...,
        av_profile: str | None = ...,
        webfilter_profile_status: Literal["enable", "disable"] | None = ...,
        webfilter_profile: str | None = ...,
        emailfilter_profile_status: Literal["enable", "disable"] | None = ...,
        emailfilter_profile: str | None = ...,
        dlp_profile_status: Literal["enable", "disable"] | None = ...,
        dlp_profile: str | None = ...,
        ip_threatfeed_status: Literal["enable", "disable"] | None = ...,
        ip_threatfeed: str | list[str] | list[SnifferIpthreatfeedItem] | None = ...,
        file_filter_profile_status: Literal["enable", "disable"] | None = ...,
        file_filter_profile: str | None = ...,
        ips_dos_status: Literal["enable", "disable"] | None = ...,
        anomaly: str | list[str] | list[SnifferAnomalyItem] | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> SnifferObject: ...

    # ================================================================
    # PUT Method
    # ================================================================
    
    def put(
        self,
        payload_dict: SnifferPayload | None = ...,
        id: int | None = ...,
        uuid: str | None = ...,
        status: Literal["enable", "disable"] | None = ...,
        logtraffic: Literal["all", "utm", "disable"] | None = ...,
        ipv6: Literal["enable", "disable"] | None = ...,
        non_ip: Literal["enable", "disable"] | None = ...,
        interface: str | None = ...,
        host: str | None = ...,
        port: str | None = ...,
        protocol: str | None = ...,
        vlan: str | None = ...,
        application_list_status: Literal["enable", "disable"] | None = ...,
        application_list: str | None = ...,
        ips_sensor_status: Literal["enable", "disable"] | None = ...,
        ips_sensor: str | None = ...,
        dsri: Literal["enable", "disable"] | None = ...,
        av_profile_status: Literal["enable", "disable"] | None = ...,
        av_profile: str | None = ...,
        webfilter_profile_status: Literal["enable", "disable"] | None = ...,
        webfilter_profile: str | None = ...,
        emailfilter_profile_status: Literal["enable", "disable"] | None = ...,
        emailfilter_profile: str | None = ...,
        dlp_profile_status: Literal["enable", "disable"] | None = ...,
        dlp_profile: str | None = ...,
        ip_threatfeed_status: Literal["enable", "disable"] | None = ...,
        ip_threatfeed: str | list[str] | list[SnifferIpthreatfeedItem] | None = ...,
        file_filter_profile_status: Literal["enable", "disable"] | None = ...,
        file_filter_profile: str | None = ...,
        ips_dos_status: Literal["enable", "disable"] | None = ...,
        anomaly: str | list[str] | list[SnifferAnomalyItem] | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> SnifferObject: ...

    # ================================================================
    # DELETE Method
    # ================================================================
    
    def delete(
        self,
        id: int | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> FortiObject[Any]: ...

    # ================================================================
    # Utility Methods
    # ================================================================
    
    def exists(
        self,
        id: int,
        vdom: str | bool | None = ...,
    ) -> bool: ...
    
    def set(
        self,
        payload_dict: SnifferPayload | None = ...,
        id: int | None = ...,
        uuid: str | None = ...,
        status: Literal["enable", "disable"] | None = ...,
        logtraffic: Literal["all", "utm", "disable"] | None = ...,
        ipv6: Literal["enable", "disable"] | None = ...,
        non_ip: Literal["enable", "disable"] | None = ...,
        interface: str | None = ...,
        host: str | None = ...,
        port: str | None = ...,
        protocol: str | None = ...,
        vlan: str | None = ...,
        application_list_status: Literal["enable", "disable"] | None = ...,
        application_list: str | None = ...,
        ips_sensor_status: Literal["enable", "disable"] | None = ...,
        ips_sensor: str | None = ...,
        dsri: Literal["enable", "disable"] | None = ...,
        av_profile_status: Literal["enable", "disable"] | None = ...,
        av_profile: str | None = ...,
        webfilter_profile_status: Literal["enable", "disable"] | None = ...,
        webfilter_profile: str | None = ...,
        emailfilter_profile_status: Literal["enable", "disable"] | None = ...,
        emailfilter_profile: str | None = ...,
        dlp_profile_status: Literal["enable", "disable"] | None = ...,
        dlp_profile: str | None = ...,
        ip_threatfeed_status: Literal["enable", "disable"] | None = ...,
        ip_threatfeed: str | list[str] | list[SnifferIpthreatfeedItem] | None = ...,
        file_filter_profile_status: Literal["enable", "disable"] | None = ...,
        file_filter_profile: str | None = ...,
        ips_dos_status: Literal["enable", "disable"] | None = ...,
        anomaly: str | list[str] | list[SnifferAnomalyItem] | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> FortiObject[Any]: ...
    
    # Helper methods
    @staticmethod
    def help(field_name: str | None = ...) -> str: ...
    
    @staticmethod
    def fields(detailed: bool = ...) -> list[str] | list[dict[str, Any]]: ...
    
    @staticmethod
    def field_info(field_name: str) -> FortiObject[Any]: ...
    
    @staticmethod
    def validate_field(name: str, value: Any) -> bool: ...
    
    @staticmethod
    def required_fields() -> list[str]: ...
    
    @staticmethod
    def defaults() -> FortiObject[Any]: ...
    
    @staticmethod
    def schema() -> FortiObject[Any]: ...


__all__ = [
    "Sniffer",
    "SnifferPayload",
    "SnifferResponse",
    "SnifferObject",
]


""" - Type Stubs

Auto-generated stub file for type checking and IDE support.

Endpoint: wireless_controller/global_
Category: cmdb
"""

from __future__ import annotations

from typing import (
    Any,
    ClassVar,
    Literal,
    TypedDict,
)

from hfortix_fortios.models import (
    FortiObject,
    FortiObjectList,
)


# ================================================================
# TypedDict Payloads
# ================================================================

class GlobalPayload(TypedDict, total=False):
    """Payload type for Global operations."""
    name: str
    location: str
    acd_process_count: int
    wpad_process_count: int
    image_download: Literal["enable", "disable"]
    rolling_wtp_upgrade: Literal["enable", "disable"]
    rolling_wtp_upgrade_threshold: str
    max_retransmit: int
    control_message_offload: str | list[str]
    data_ethernet_II: Literal["enable", "disable"]
    link_aggregation: Literal["enable", "disable"]
    mesh_eth_type: int
    fiapp_eth_type: int
    discovery_mc_addr: str
    discovery_mc_addr6: str
    max_clients: int
    rogue_scan_mac_adjacency: int
    ipsec_base_ip: str
    wtp_share: Literal["enable", "disable"]
    tunnel_mode: Literal["compatible", "strict"]
    nac_interval: int
    ap_log_server: Literal["enable", "disable"]
    ap_log_server_ip: str
    ap_log_server_port: int
    max_sta_offline: int
    max_sta_offline_ip2mac: int
    max_sta_cap: int
    max_sta_cap_wtp: int
    max_rogue_ap: int
    max_rogue_ap_wtp: int
    max_rogue_sta: int
    max_wids_entry: int
    max_ble_device: int


# ================================================================
# Response Types (TypedDict for dict-style access)
# ================================================================

class GlobalResponse(TypedDict, total=False):
    """Response type for Global - use with .dict property for typed dict access."""
    name: str
    location: str
    acd_process_count: int
    wpad_process_count: int
    image_download: Literal["enable", "disable"]
    rolling_wtp_upgrade: Literal["enable", "disable"]
    rolling_wtp_upgrade_threshold: str
    max_retransmit: int
    control_message_offload: str
    data_ethernet_II: Literal["enable", "disable"]
    link_aggregation: Literal["enable", "disable"]
    mesh_eth_type: int
    fiapp_eth_type: int
    discovery_mc_addr: str
    discovery_mc_addr6: str
    max_clients: int
    rogue_scan_mac_adjacency: int
    ipsec_base_ip: str
    wtp_share: Literal["enable", "disable"]
    tunnel_mode: Literal["compatible", "strict"]
    nac_interval: int
    ap_log_server: Literal["enable", "disable"]
    ap_log_server_ip: str
    ap_log_server_port: int
    max_sta_offline: int
    max_sta_offline_ip2mac: int
    max_sta_cap: int
    max_sta_cap_wtp: int
    max_rogue_ap: int
    max_rogue_ap_wtp: int
    max_rogue_sta: int
    max_wids_entry: int
    max_ble_device: int


# ================================================================
# Response Types (Class for attribute access)
# ================================================================


class GlobalObject(FortiObject):
    """Typed FortiObject for Global with field access."""
    name: str
    location: str
    acd_process_count: int
    wpad_process_count: int
    image_download: Literal["enable", "disable"]
    rolling_wtp_upgrade: Literal["enable", "disable"]
    rolling_wtp_upgrade_threshold: str
    max_retransmit: int
    control_message_offload: str
    data_ethernet_II: Literal["enable", "disable"]
    link_aggregation: Literal["enable", "disable"]
    mesh_eth_type: int
    fiapp_eth_type: int
    discovery_mc_addr: str
    discovery_mc_addr6: str
    max_clients: int
    rogue_scan_mac_adjacency: int
    ipsec_base_ip: str
    wtp_share: Literal["enable", "disable"]
    tunnel_mode: Literal["compatible", "strict"]
    nac_interval: int
    ap_log_server: Literal["enable", "disable"]
    ap_log_server_ip: str
    ap_log_server_port: int
    max_sta_offline: int
    max_sta_offline_ip2mac: int
    max_sta_cap: int
    max_sta_cap_wtp: int
    max_rogue_ap: int
    max_rogue_ap_wtp: int
    max_rogue_sta: int
    max_wids_entry: int
    max_ble_device: int


# ================================================================
# Main Endpoint Class
# ================================================================

class Global:
    """
    
    Endpoint: wireless_controller/global_
    Category: cmdb
    """
    
    # Class attributes for introspection
    endpoint: ClassVar[str] = ...
    path: ClassVar[str] = ...
    category: ClassVar[str] = ...
    capabilities: ClassVar[dict[str, Any]] = ...
    
    def __init__(self, client: Any) -> None:
        """Initialize endpoint with HTTP client."""
        ...
    
    # ================================================================
    # GET Methods
    # ================================================================
    
    # Singleton endpoint (no mkey)
    def get(
        self,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> GlobalObject: ...
    
    def get_schema(
        self,
        format: str = ...,
    ) -> FortiObject: ...


    # ================================================================
    # PUT Method
    # ================================================================
    
    def put(
        self,
        payload_dict: GlobalPayload | None = ...,
        name: str | None = ...,
        location: str | None = ...,
        acd_process_count: int | None = ...,
        wpad_process_count: int | None = ...,
        image_download: Literal["enable", "disable"] | None = ...,
        rolling_wtp_upgrade: Literal["enable", "disable"] | None = ...,
        rolling_wtp_upgrade_threshold: str | None = ...,
        max_retransmit: int | None = ...,
        control_message_offload: str | list[str] | None = ...,
        data_ethernet_II: Literal["enable", "disable"] | None = ...,
        link_aggregation: Literal["enable", "disable"] | None = ...,
        mesh_eth_type: int | None = ...,
        fiapp_eth_type: int | None = ...,
        discovery_mc_addr: str | None = ...,
        discovery_mc_addr6: str | None = ...,
        max_clients: int | None = ...,
        rogue_scan_mac_adjacency: int | None = ...,
        ipsec_base_ip: str | None = ...,
        wtp_share: Literal["enable", "disable"] | None = ...,
        tunnel_mode: Literal["compatible", "strict"] | None = ...,
        nac_interval: int | None = ...,
        ap_log_server: Literal["enable", "disable"] | None = ...,
        ap_log_server_ip: str | None = ...,
        ap_log_server_port: int | None = ...,
        max_sta_offline: int | None = ...,
        max_sta_offline_ip2mac: int | None = ...,
        max_sta_cap: int | None = ...,
        max_sta_cap_wtp: int | None = ...,
        max_rogue_ap: int | None = ...,
        max_rogue_ap_wtp: int | None = ...,
        max_rogue_sta: int | None = ...,
        max_wids_entry: int | None = ...,
        max_ble_device: int | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> GlobalObject: ...


    # ================================================================
    # Utility Methods
    # ================================================================
    
    def exists(
        self,
        name: str,
    ) -> bool: ...
    
    def set(
        self,
        payload_dict: GlobalPayload | None = ...,
        name: str | None = ...,
        location: str | None = ...,
        acd_process_count: int | None = ...,
        wpad_process_count: int | None = ...,
        image_download: Literal["enable", "disable"] | None = ...,
        rolling_wtp_upgrade: Literal["enable", "disable"] | None = ...,
        rolling_wtp_upgrade_threshold: str | None = ...,
        max_retransmit: int | None = ...,
        control_message_offload: Literal["ebp-frame", "aeroscout-tag", "ap-list", "sta-list", "sta-cap-list", "stats", "aeroscout-mu", "sta-health", "spectral-analysis"] | list[str] | None = ...,
        data_ethernet_II: Literal["enable", "disable"] | None = ...,
        link_aggregation: Literal["enable", "disable"] | None = ...,
        mesh_eth_type: int | None = ...,
        fiapp_eth_type: int | None = ...,
        discovery_mc_addr: str | None = ...,
        discovery_mc_addr6: str | None = ...,
        max_clients: int | None = ...,
        rogue_scan_mac_adjacency: int | None = ...,
        ipsec_base_ip: str | None = ...,
        wtp_share: Literal["enable", "disable"] | None = ...,
        tunnel_mode: Literal["compatible", "strict"] | None = ...,
        nac_interval: int | None = ...,
        ap_log_server: Literal["enable", "disable"] | None = ...,
        ap_log_server_ip: str | None = ...,
        ap_log_server_port: int | None = ...,
        max_sta_offline: int | None = ...,
        max_sta_offline_ip2mac: int | None = ...,
        max_sta_cap: int | None = ...,
        max_sta_cap_wtp: int | None = ...,
        max_rogue_ap: int | None = ...,
        max_rogue_ap_wtp: int | None = ...,
        max_rogue_sta: int | None = ...,
        max_wids_entry: int | None = ...,
        max_ble_device: int | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> FortiObject[Any]: ...
    
    # Helper methods
    @staticmethod
    def help(field_name: str | None = ...) -> str: ...
    
    @staticmethod
    def fields(detailed: bool = ...) -> list[str] | list[dict[str, Any]]: ...
    
    @staticmethod
    def field_info(field_name: str) -> FortiObject[Any]: ...
    
    @staticmethod
    def validate_field(name: str, value: Any) -> bool: ...
    
    @staticmethod
    def required_fields() -> list[str]: ...
    
    @staticmethod
    def defaults() -> FortiObject[Any]: ...
    
    @staticmethod
    def schema() -> FortiObject[Any]: ...


__all__ = [
    "Global",
    "GlobalPayload",
    "GlobalResponse",
    "GlobalObject",
]


"""FortiOS CMDB - Dhcp category"""

from ..dhcp_base import Dhcp as DhcpBase
from .revoke import Revoke

__all__ = [
    "Dhcp",
    "Revoke",
]


class Dhcp(DhcpBase):
    """Dhcp endpoints wrapper for CMDB API."""

    def __init__(self, client):
        """Dhcp endpoints.
        
        Args:
            client: HTTP client instance for API communication
        """
        super().__init__(client)  # Initialize base class with GET methods
        self.revoke = Revoke(client)



"""Type stubs for LOG fortianalyzer endpoints."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient

from hfortix_fortios.models import FortiObjectList


class Fortianalyzer:
    """Fortianalyzer log operations."""
    anomaly: FortianalyzerAnomaly
    app_ctrl: FortianalyzerAppCtrl
    cifs: FortianalyzerCifs
    dlp: FortianalyzerDlp
    dns: FortianalyzerDns
    emailfilter: FortianalyzerEmailfilter
    event: FortianalyzerEvent
    file_filter: FortianalyzerFileFilter
    gtp: FortianalyzerGtp
    ips: FortianalyzerIps
    ssh: FortianalyzerSsh
    ssl: FortianalyzerSsl
    traffic: FortianalyzerTraffic
    virus: FortianalyzerVirus
    voip: FortianalyzerVoip
    waf: FortianalyzerWaf
    webfilter: FortianalyzerWebfilter

    def __init__(self, client: IHTTPClient) -> None: ...


class FortianalyzerAnomaly:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerAnomalyRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get anomaly logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerAppCtrl:
    """Log data for the given log type (and subtype)."""
    archive: FortianalyzerAppCtrlArchive
    raw: FortianalyzerAppCtrlRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get app_ctrl logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerCifs:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerCifsRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get cifs logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerDlp:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerDlpRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get dlp logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerDns:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerDnsRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get dns logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEmailfilter:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEmailfilterRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get emailfilter logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEvent:
    """FortianalyzerEvent log category."""
    compliance_check: FortianalyzerEventComplianceCheck
    connector: FortianalyzerEventConnector
    endpoint: FortianalyzerEventEndpoint
    fortiextender: FortianalyzerEventFortiextender
    ha: FortianalyzerEventHa
    router: FortianalyzerEventRouter
    security_rating: FortianalyzerEventSecurityRating
    system: FortianalyzerEventSystem
    user: FortianalyzerEventUser
    vpn: FortianalyzerEventVpn
    wad: FortianalyzerEventWad
    wireless: FortianalyzerEventWireless

    def __init__(self, client: IHTTPClient) -> None: ...

class FortianalyzerFileFilter:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerFileFilterRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get file_filter logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerGtp:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerGtpRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get gtp logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerIps:
    """Log data for the given log type (and subtype)."""
    archive: FortianalyzerIpsArchive
    raw: FortianalyzerIpsRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get ips logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerSsh:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerSshRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get ssh logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerSsl:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerSslRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get ssl logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTraffic:
    """FortianalyzerTraffic log category."""
    fortiview: FortianalyzerTrafficFortiview
    forward: FortianalyzerTrafficForward
    local: FortianalyzerTrafficLocal
    multicast: FortianalyzerTrafficMulticast
    sniffer: FortianalyzerTrafficSniffer
    threat: FortianalyzerTrafficThreat

    def __init__(self, client: IHTTPClient) -> None: ...

class FortianalyzerVirus:
    """Log data for the given log type (and subtype)."""
    archive: FortianalyzerVirusArchive
    raw: FortianalyzerVirusRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get virus logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerVoip:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerVoipRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get voip logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerWaf:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerWafRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get waf logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerWebfilter:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerWebfilterRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get webfilter logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerAnomalyRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get anomaly raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerAppCtrlArchive:
    """Return a list of archived items for the desired type."""
    download: FortianalyzerAppCtrlArchiveDownload

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get app_ctrl archive logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerAppCtrlRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get app_ctrl raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerCifsRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get cifs raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerDlpRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get dlp raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerDnsRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get dns raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEmailfilterRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get emailfilter raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventComplianceCheck:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventComplianceCheckRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event compliance_check logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventConnector:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventConnectorRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event connector logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventEndpoint:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventEndpointRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event endpoint logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventFortiextender:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventFortiextenderRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event fortiextender logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventHa:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventHaRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event ha logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventRouter:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventRouterRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event router logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventSecurityRating:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventSecurityRatingRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event security_rating logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventSystem:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventSystemRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event system logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventUser:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventUserRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event user logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventVpn:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventVpnRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event vpn logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventWad:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventWadRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event wad logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventWireless:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerEventWirelessRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event wireless logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerFileFilterRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get file_filter raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerGtpRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get gtp raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerIpsArchive:
    """Return a list of archived items for the desired type."""
    download: FortianalyzerIpsArchiveDownload

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get ips archive logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerIpsRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get ips raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerSshRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get ssh raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerSslRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get ssl raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficFortiview:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerTrafficFortiviewRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic fortiview logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficForward:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerTrafficForwardRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic forward logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficLocal:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerTrafficLocalRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic local logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficMulticast:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerTrafficMulticastRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic multicast logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficSniffer:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerTrafficSnifferRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic sniffer logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficThreat:
    """Log data for the given log type (and subtype)."""
    raw: FortianalyzerTrafficThreatRaw

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic threat logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerVirusArchive:
    """Return a description of the quarantined virus file."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get virus archive logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerVirusRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get virus raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerVoipRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get voip raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerWafRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get waf raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerWebfilterRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get webfilter raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerAppCtrlArchiveDownload:
    """Download an archived file."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get app_ctrl archive download logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventComplianceCheckRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event compliance_check raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventConnectorRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event connector raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventEndpointRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event endpoint raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventFortiextenderRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event fortiextender raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventHaRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event ha raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventRouterRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event router raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventSecurityRatingRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event security_rating raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventSystemRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event system raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventUserRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event user raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventVpnRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event vpn raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventWadRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event wad raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerEventWirelessRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get event wireless raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerIpsArchiveDownload:
    """Download an archived file."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get ips archive download logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficFortiviewRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic fortiview raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficForwardRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic forward raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficLocalRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic local raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficMulticastRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic multicast raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficSnifferRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic sniffer raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...

class FortianalyzerTrafficThreatRaw:
    """Log data for the given log type in raw format."""

    def __init__(self, client: IHTTPClient) -> None: ...

    def get(
        self,
        *,
        rows: int | None = None,
        session_id: int | None = None,
        serial_no: str | None = None,
        is_ha_member: bool | None = None,
        filter: str | None = None,
        extra: str | None = None,
        vdom: str | None = None,
    ) -> FortiObjectList:
        """
        Get traffic threat raw logs.

        Args:
            rows: Number of rows to return
            session_id: Session ID for paginated retrieval
            serial_no: Retrieve logs from specific device
            is_ha_member: Whether the device is an HA member
            filter: Filter expression
            extra: Extra data flags
            vdom: Virtual domain

        Returns:
            FortiObjectList containing log records
        """
        ...
